@@ -1,6 +1,6 @@
 use std::collections::HashMap;
 
-use manifest::npm::repository::Repository;
+use crate::manifest::npm::repository::Repository;
 
 #[derive(Serialize)]
 pub struct NoModulesPackage {
