@@ -1,8 +1,7 @@
+extern crate anyhow;
 extern crate assert_cmd;
-extern crate failure;
-extern crate predicates;
-#[macro_use]
 extern crate lazy_static;
+extern crate predicates;
 #[macro_use]
 extern crate serde_derive;
 extern crate binary_install;
